@@ -1459,7 +1459,10 @@ class Builder(Update):
         dv = self.clVars.Get('builder.cl_builder_linux_datavars')
         if dv:
             deo = dv.Get('cl_emerge_default_opts')
-            if depclean and dv.GetBool('update.cl_update_with_bdeps_set'):
+            bdeps_val = self.clVars.Get('cl_builder_with_bdeps_opt_set')
+            if bdeps_val == "auto":
+                bdeps = " --with-bdeps-auto=y"
+            elif bdeps_val == "on":
                 bdeps = " --with-bdeps=y"
             else:
                 bdeps = " --with-bdeps=n"
